# Generated by Django 3.2.18 on 2023-04-20 15:08

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("djangocms_htmlsitemap", "0002_auto_20180228_1210"),
    ]

    operations = [
        migrations.AlterField(
            model_name="htmlsitemappluginconf",
            name="in_navigation",
            field=models.BooleanField(
                default=None, null=True, verbose_name="In navigation"
            ),
        ),
    ]



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class HtmlSitemapConfig(AppConfig):
    name = "djangocms_htmlsitemap"
    verbose_name = _("HTML Sitemap")
    default_auto_field = "django.db.models.AutoField"



from cms.models import CMSPlugin
from django.db import models
from django.utils.translation import gettext_lazy as _


class HtmlSitemapPluginConf(CMSPlugin):
    min_depth = models.PositiveIntegerField(verbose_name=_("Minimum depth"), default=0)
    max_depth = models.PositiveIntegerField(
        verbose_name=_("Maximum depth"), blank=True, null=True
    )
    in_navigation = models.BooleanField(
        verbose_name=_("In navigation"), default=None, null=True
    )

    class Meta:
        verbose_name = _("HTML Sitemap plugin configuration")
        verbose_name_plural = _("HTML Sitemap plugin configurations")

    def __str__(self):
        return "Django-CMS HTML Sitemap #{}".format(self.pk)



from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("cms", "0011_auto_20150419_1006")]

    operations = [
        migrations.CreateModel(
            name="HtmlSitemapPluginConf",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        parent_link=True,
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        to="cms.CMSPlugin",
                        on_delete=models.SET_NULL,
                    ),
                ),
                (
                    "min_depth",
                    models.PositiveIntegerField(
                        default=0, verbose_name="Minimum depth"
                    ),
                ),
                (
                    "max_depth",
                    models.PositiveIntegerField(
                        null=True, verbose_name="Maximum depth", blank=True
                    ),
                ),
                (
                    "in_navigation",
                    models.NullBooleanField(default=None, verbose_name="In navigation"),
                ),
            ],
            options={
                "verbose_name": "HTML Sitemap plugin configuration",
                "verbose_name_plural": "HTML Sitemap plugin configurations",
            },
            bases=("cms.cmsplugin",),
        )
    ]



# Generated by Django 1.11.7 on 2018-02-28 11:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("djangocms_htmlsitemap", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="htmlsitemappluginconf",
            name="cmsplugin_ptr",
            field=models.OneToOneField(
                auto_created=True,
                on_delete=django.db.models.deletion.CASCADE,
                parent_link=True,
                primary_key=True,
                related_name="djangocms_htmlsitemap_htmlsitemappluginconf",
                serialize=False,
                to="cms.CMSPlugin",
            ),
        )
    ]



from cms.models.pagemodel import Page, TreeNode
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.contrib.sites.models import Site
from django.utils.translation import gettext_lazy as _

from .models import HtmlSitemapPluginConf


class HtmlSitemapPlugin(CMSPluginBase):
    model = HtmlSitemapPluginConf
    name = _("HTML Sitemap")

    render_template = "djangocms_htmlsitemap/sitemap.html"

    def render(self, context, instance, placeholder):
        request = context["request"]
        language = request.LANGUAGE_CODE

        site = Site.objects.get_current()

        path_column = "node__path"
        node_column = "node__depth"

        pages = (
            Page.objects.public()
            .published(site=site)
            .order_by(path_column)
            .filter(login_required=False, **{node_column + "__gte": instance.min_depth})
            .filter(title_set__language=language)
            .distinct()
        )

        if instance.max_depth:
            pages = pages.filter(**{node_column + "__lte": instance.max_depth})
        if instance.in_navigation is not None:
            pages = pages.filter(in_navigation=instance.in_navigation)

        context["instance"] = instance
        context["pages"] = pages

        nodes = [page.node for page in pages.select_related("node")]
        annotated_nodes = TreeNode.get_annotated_list_qs(nodes)
        annotated_pages = [
            (pages[x], annotated_nodes[x][1]) for x in range(0, len(nodes))
        ]

        context["annotated_pages"] = annotated_pages

        return context


plugin_pool.register_plugin(HtmlSitemapPlugin)
